package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a question that allows selection between two choices.
 * 
 * @author liu
 *
 * @param <T> The type of object representing the choices.
 */
public class BinaryChoiceQuestion<T> extends ChoiceQuestion<BinaryChoice<T>> {

	private BinaryChoiceQuestion(String newPrompt, List<BinaryChoice<T>> choices) throws InvalidChoiceListException {
		super(newPrompt, Boolean.class, choices);
	}
	
	 /**
	  * Factory method for creating a <code>BinaryChoiceQuestion</code>.
	  * 
	  * @param <T> Type of object to use to represent the choices
	  * @param prompt prompt of the question
	  * @param falseChoice object to represent the choice 'false'
	  * @param trueChoice object to represent the choice 'true'
	  * @return new <code>BinaryChoiceQuestion</code>
	  */
	public static <T> BinaryChoiceQuestion<T> makeBinaryChoiceQuestion(String prompt, T falseChoice, T trueChoice) {
		List<BinaryChoice<T>> choiceList = new ArrayList<BinaryChoice<T>>();
		choiceList.add(new BinaryChoice<T>(false, falseChoice));
		choiceList.add(new BinaryChoice<T>(true, trueChoice));
		try {
			return new BinaryChoiceQuestion<T>(prompt, choiceList);
		} catch (InvalidChoiceListException e) {
			//cannot have null choice list; code will not get here
		}
		return null; //will never execute;
	}

	@Override
	public List<Statistic> aggregate(List<Object> listOfAnswers) {
		return null;
	}

}
