package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

import java.util.Map;
import java.util.TreeMap;

/**
 * Represents a response to a survey. Question numbers are mapped to responses.
 * @author liu
 *
 */
public class ResponseSet {
    private Map<Integer, Object> answerSet;
    private Survey survey;
    
    /**
     * Creates an empty responseSet to answer the specified survey
     * @param targetSurvey
     */
    public ResponseSet(Survey targetSurvey) throws InvalidSurveyException {
        if (targetSurvey == null)
        	throw new InvalidSurveyException("Survey cannot be null");
    	survey = targetSurvey;
        answerSet = new TreeMap<Integer, Object>();
    }
    
    /**
     * Answer the specified question with the specified answer
     * @param answer the answer to provide
     * @param question the question number to answer
     * @throws NoSuchQustionException if specified question number does not exist
     * @throws InvalidAnswerException if specified question does not accept given answer
     */
    public void answerQuestion(int index, Object answer) throws NoSuchQuestionException, InvalidAnswerException {
        if (survey.getQuestionAt(index).validate(answer))
        	answerSet.put(index, answer);
        else
        	throw new InvalidAnswerException();
    }
    
    /**
     * get the answer to the specified question
     * 
     * @param i question number to look up
     * @return object representing the response to the question, or null if question was not answered.
     */
    public Object getAnswerForQuestion(int i) {
    	return answerSet.get(i);
    }
    
    /**
     * removes an answer to a question
     * 
     * @param index index of question to remove response from
     * @throws NoSuchQustionException if index >= number of questions
     */
    public boolean removeAnswer(int index) throws NoSuchQuestionException {
    	if (index < survey.getNumberOfQuestions()) {
    		if (answerSet.get(index) != null) {
    			answerSet.remove(index);
    			return true;
    		}
    		else
    			return false;
    	}
    	else
    		throw new NoSuchQuestionException();
    }
}
